@@ -1,6 +1,21 @@
 from urllib import urlencode, quote_plus
 import urllib2
-from functools import partial
+
+
+try:
+    import functools
+    partial = functools.partial
+except ImportError:
+    def partial(func, *args, **keywords):
+        def newfunc(*fargs, **fkeywords):
+            newkeywords = keywords.copy()
+            newkeywords.update(fkeywords)
+            return func(*(args + fargs), **newkeywords)
+        newfunc.func = func
+        newfunc.args = args
+        newfunc.keywords = keywords
+        return newfunc
+
 
 try:
     import json
